#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hspec-golden
version:              0.2.2.0
visibility:           public
id:                   hspec-golden-0.2.2.0-EFx2xQp8G5i9GwzeTBQAem
key:                  hspec-golden-0.2.2.0-EFx2xQp8G5i9GwzeTBQAem
license:              MIT
copyright:            2019-Present Stack Builders Inc
maintainer:           Cristhian Motoche <cmotoche@stackbuilders.com>
author:               Stack Builders
homepage:             https://github.com/stackbuilders/hspec-golden#readme
synopsis:             Golden tests for hspec
description:

    Golden tests store the expected output in a separated file. Each time a golden test
    is executed the output of the subject under test (SUT) is compared with the
    expected output. If the output of the SUT changes then the test will fail until
    the expected output is updated.

    @hspec-golden@ allows you to write golden tests using the popular @hspec@.

    > describe "myFunc" $
    >   it "generates the right output with the right params" $
    >      let output = show $ myFunc params
    >        in defaultGolden "myFunc" output

    Please see the <https://github.com/stackbuilders/hspec-golden#readme README on GitHub>
    for more information.

category:             Testing
abi:                  b87dd8d56400f67f40a2a44de179cca5
exposed:              True
exposed-modules:      Test.Hspec.Golden
hidden-modules:       Paths_hspec_golden
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hspec-golden-0.2.2.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hspec-golden-0.2.2.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hspec-golden-0.2.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hspec-golden
hs-libraries:         HShspec-golden-0.2.2.0-EFx2xQp8G5i9GwzeTBQAem
depends:
    base-4.18.2.1 directory-1.3.8.5 filepath-1.4.300.1
    hspec-core-2.11.6-GiCba454bvnJzVr5eiNoX6

haddock-interfaces:
    /usr/share/doc/haskell-hspec-golden/html/hspec-golden.haddock

haddock-html:         /usr/share/doc/haskell-hspec-golden/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

